searchData={"items":[{"type":"module","title":"Caddy","doc":"# Caddy\n\nStart Caddy HTTP Server in supervisor tree\n\n- Start in your application\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # Start a Caddy by calling: Caddy.start_link([])\n    {Caddy, [\n      caddy_bin: \"/usr/bin/caddy\",\n    ]}\n    # Start the Telemetry supervisor\n    PhoenixWeb.Telemetry,\n    # Start the PubSub system\n    {Phoenix.PubSub, name: PhoenixWeb.PubSub},\n    # Start the Endpoint (http/https)\n    PhoenixWeb.Endpoint\n  ]\n\n  opts = [strategy: :one_for_one, name: PhoenixWeb.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\n- Start in extra_applications\n\n```elixir\ndef application do\n  [\n    extra_applications: [Caddy.Application]\n  ]\nend\n```\n\n* Notice\n\nIf caddy_bin is not specifiy, Caddy.Server will not start.\n\nSet `caddy_bin` to the path of Caddy binary file and start `Caddy.Server`.\n\n```\nCaddy.Cofnig.set_bin(\"/usr/bin/caddy\")\nCaddy.restart_server()\n```\n\nThis will restart server automatically\n\n```\nCaddy.Cofnig.set_bin!(\"/usr/bin/caddy\")\n```","ref":"Caddy.html"},{"type":"function","title":"Caddy.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.html#child_spec/1"},{"type":"function","title":"Caddy.restart_server/0","doc":"Restart Caddy Server","ref":"Caddy.html#restart_server/0"},{"type":"function","title":"Caddy.start/0","doc":"","ref":"Caddy.html#start/0"},{"type":"function","title":"Caddy.start/1","doc":"Manually Start Caddy Server.\n\nThis is useful when you want to start Caddy Server in `iex` console.","ref":"Caddy.html#start/1"},{"type":"function","title":"Caddy.start_link/1","doc":"","ref":"Caddy.html#start_link/1"},{"type":"function","title":"Caddy.stop/1","doc":"","ref":"Caddy.html#stop/1"},{"type":"module","title":"Caddy.Config","doc":"Start Caddy Config process to manage Caddy configuration.\n\nConfiguration is stored in `%Caddy.Config{}` struct in `Caddy.Config` process.\n\n```\n%Caddy.Config{\n  bin: binary() | nil,\n  global: binary(),\n  additional: [binary()],\n  sites: map(),\n  env: list({binary(), binary()})\n}\n```","ref":"Caddy.Config.html"},{"type":"function","title":"Caddy.Config.adapt/1","doc":"Convert caddyfile to json format.","ref":"Caddy.Config.html#adapt/1"},{"type":"type","title":"Caddy.Config.caddyfile/0","doc":"","ref":"Caddy.Config.html#t:caddyfile/0"},{"type":"function","title":"Caddy.Config.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Config.html#child_spec/1"},{"type":"function","title":"Caddy.Config.env_file/0","doc":"","ref":"Caddy.Config.html#env_file/0"},{"type":"function","title":"Caddy.Config.etc_path/0","doc":"","ref":"Caddy.Config.html#etc_path/0"},{"type":"function","title":"Caddy.Config.get/1","doc":"Get the :key in Caddy Cofnig","ref":"Caddy.Config.html#get/1"},{"type":"function","title":"Caddy.Config.get_config/0","doc":"Return the current configuration in `Caddy.Config`","ref":"Caddy.Config.html#get_config/0"},{"type":"function","title":"Caddy.Config.init/1","doc":"","ref":"Caddy.Config.html#init/1"},{"type":"function","title":"Caddy.Config.init_file/0","doc":"","ref":"Caddy.Config.html#init_file/0"},{"type":"function","title":"Caddy.Config.pid_file/0","doc":"","ref":"Caddy.Config.html#pid_file/0"},{"type":"function","title":"Caddy.Config.priv_path/0","doc":"","ref":"Caddy.Config.html#priv_path/0"},{"type":"function","title":"Caddy.Config.run_path/0","doc":"","ref":"Caddy.Config.html#run_path/0"},{"type":"function","title":"Caddy.Config.saved/0","doc":"","ref":"Caddy.Config.html#saved/0"},{"type":"function","title":"Caddy.Config.saved_json_file/0","doc":"","ref":"Caddy.Config.html#saved_json_file/0"},{"type":"function","title":"Caddy.Config.set_bin/1","doc":"Set the Caddy binary path","ref":"Caddy.Config.html#set_bin/1"},{"type":"function","title":"Caddy.Config.set_bin!/1","doc":"Set the caddy binary path and restart Caddy.Server","ref":"Caddy.Config.html#set_bin!/1"},{"type":"function","title":"Caddy.Config.set_config/1","doc":"Replace the current configuration in `Caddy.Config`","ref":"Caddy.Config.html#set_config/1"},{"type":"function","title":"Caddy.Config.set_global/1","doc":"Set the global configuration\n\n```\nCaddy.Config.set_global(\"\"\"\ndebug\nauto_https off\n\"\"\")\n```","ref":"Caddy.Config.html#set_global/1"},{"type":"function","title":"Caddy.Config.set_site/2","doc":"Set the site configuration\n\n```\nCaddy.Config.set_site(\"www.gsmlg.com\", \"\"\"\nreverse_proxy {\n  to localhost:4000\n  header_up host www.gsmlg.com\n  header_up X-Real-IP {remote_host}\n}\n\"\"\")\n# or\nCaddy.Config.set_site(\"proxy\", {\":8080\", \"\"\"\nreverse_proxy {\n  to localhost:3128\n}\n\"\"\"})\n```","ref":"Caddy.Config.html#set_site/2"},{"type":"function","title":"Caddy.Config.share_path/0","doc":"","ref":"Caddy.Config.html#share_path/0"},{"type":"type","title":"Caddy.Config.site_config/0","doc":"","ref":"Caddy.Config.html#t:site_config/0"},{"type":"type","title":"Caddy.Config.site_listen/0","doc":"","ref":"Caddy.Config.html#t:site_listen/0"},{"type":"type","title":"Caddy.Config.site_name/0","doc":"","ref":"Caddy.Config.html#t:site_name/0"},{"type":"function","title":"Caddy.Config.socket_file/0","doc":"","ref":"Caddy.Config.html#socket_file/0"},{"type":"function","title":"Caddy.Config.start_link/1","doc":"","ref":"Caddy.Config.html#start_link/1"},{"type":"type","title":"Caddy.Config.t/0","doc":"","ref":"Caddy.Config.html#t:t/0"},{"type":"function","title":"Caddy.Config.tmp_path/0","doc":"","ref":"Caddy.Config.html#tmp_path/0"},{"type":"function","title":"Caddy.Config.to_caddyfile/1","doc":"Confirt `%Caddy.Config{}` to `caddyfile()`","ref":"Caddy.Config.html#to_caddyfile/1"},{"type":"function","title":"Caddy.Config.user_home/0","doc":"","ref":"Caddy.Config.html#user_home/0"},{"type":"function","title":"Caddy.Config.user_share/0","doc":"","ref":"Caddy.Config.html#user_share/0"},{"type":"function","title":"Caddy.Config.xdg_config_home/0","doc":"","ref":"Caddy.Config.html#xdg_config_home/0"},{"type":"function","title":"Caddy.Config.xdg_data_home/0","doc":"","ref":"Caddy.Config.html#xdg_data_home/0"},{"type":"module","title":"Caddy.Logger","doc":"Start Caddy Logger\n\nCollect caddy process logs from stdout and stderr.\n\nKeep latest `50_000` lines of logs.","ref":"Caddy.Logger.html"},{"type":"function","title":"Caddy.Logger.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Logger.html#child_spec/1"},{"type":"function","title":"Caddy.Logger.start_link/1","doc":"","ref":"Caddy.Logger.html#start_link/1"},{"type":"function","title":"Caddy.Logger.tail/1","doc":"Get latest `num` logs","ref":"Caddy.Logger.html#tail/1"},{"type":"module","title":"Caddy.Server","doc":"Caddy Server\n\nStart Caddy Server in `Port` and `GenServer` to handle the server process.\nServer outputs are save to Caddy.Logger process.\n\nWon'nt start if Caddy binary not found or not executable.\n\nCould be started by `Caddy.restart_server()` when Caddy binary is set.","ref":"Caddy.Server.html"},{"type":"function","title":"Caddy.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Server.html#child_spec/1"},{"type":"function","title":"Caddy.Server.get_caddyfile/0","doc":"Get Caddyfile content of the current running server","ref":"Caddy.Server.html#get_caddyfile/0"},{"type":"function","title":"Caddy.Server.init/1","doc":"","ref":"Caddy.Server.html#init/1"},{"type":"function","title":"Caddy.Server.start_link/1","doc":"","ref":"Caddy.Server.html#start_link/1"},{"type":"extras","title":"Elixir Caddy","doc":"# Elixir Caddy\n\n[![release](https://github.com/gsmlg-dev/elixir_caddy/actions/workflows/release.yml/badge.svg)](https://github.com/gsmlg-dev/elixir_caddy/actions/workflows/release.yml)\n\nStart `Caddy` reverse proxy server in `Elixir` project.\n\nManage caddy configuration in `Elixir`.\n\nAdd this in `deps` in `mix.exs` to install\n\n```elixir\n{:caddy, \"~> 2.0.2\"}\n```\n\nStart in Application supervisor\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # Start a Caddy by calling: Caddy.start_link([])\n    {Caddy, caddy_bin: \"/path/to/caddy\"}\n  ]\n\n  opts = [strategy: :one_for_one, name: PhoenixWeb.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\nStart in extra_applications\n\n```elixir\ndef application do\n  [\n    extra_applications: [Caddy.Application]\n  ]\nend\n```\n\n* Notice\n\nIf caddy_bin is not specifiy, Caddy.Server will not start.","ref":"readme.html"},{"type":"extras","title":"Set `Caddy` binary when needed. - Elixir Caddy","doc":"Set `caddy_bin` to the path of Caddy binary file and start `Caddy.Server`.\n\n```elixir\nCaddy.Cofnig.set_bin(\"/usr/bin/caddy\")\nCaddy.restart_server()\n```\n\nThis will restart server automatically\n\n```elixir\nCaddy.Cofnig.set_bin!(\"/usr/bin/caddy\")\n```","ref":"readme.html#set-caddy-binary-when-needed"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.0"}}